@@ -5,17 +5,19 @@ import socket
 import subprocess
 from mss import mss
 from functools import wraps
+import pywintypes  # noqa
+import win32api
 
 from pywinauto.application import Application
 from pywinauto import mouse, keyboard
 from pywinauto.win32structures import RECT
-from pywinauto.win32functions import SetForegroundWindow, GetSystemMetrics  # ,SetProcessDPIAware
+from pywinauto.win32functions import SetForegroundWindow, GetSystemMetrics
 
-from .screen import screenshot
+from airtest.core.win.ctypesinput import key_press, key_release
+from airtest.core.win.screen import screenshot
 
 from airtest import aircv
 from airtest.core.device import Device
-from airtest.core.settings import Settings as ST  # noqa
 
 
 def require_app(func):
@@ -31,6 +33,7 @@ class Windows(Device):
     """Windows client."""
 
     def __init__(self, handle=None, dpifactor=1, **kwargs):
+        super(Windows, self).__init__()
         self.app = None
         self.handle = int(handle) if handle else None
         # windows high dpi scale factor, no exact way to auto detect this value for a window
@@ -96,12 +99,14 @@ class Windows(Device):
         """
         return subprocess.check_output(cmd, shell=True)
 
-    def snapshot(self, filename=None):
+    def snapshot(self, filename=None, quality=10, max_size=None):
         """
         Take a screenshot and save it in ST.LOG_DIR folder
 
         Args:
             filename: name of the file to give to the screenshot, {time}.jpg by default
+            quality: The image quality, integer in range [1, 99]
+            max_size: the maximum size of the picture, e.g 1200
 
         Returns:
             display the screenshot
@@ -123,7 +128,7 @@ class Windows(Device):
             rect = (self._focus_rect[0], self._focus_rect[1], width + self._focus_rect[2], height + self._focus_rect[3])
             screen = aircv.crop_image(screen, rect)
         if filename:
-            aircv.imwrite(filename, screen)
+            aircv.imwrite(filename, screen, quality, max_size=max_size)
         return screen
 
     def keyevent(self, keyname, **kwargs):
@@ -167,6 +172,47 @@ class Windows(Device):
 
         return pos
 
+    def key_press(self, key):
+        """Simulates a key press event.
+
+        Sends a scancode to the computer to report which key has been pressed.
+        Some games use DirectInput devices, and respond only to scancodes, not
+        virtual key codes. You can simulate DirectInput key presses using this
+        method, instead of the keyevent() method, which uses virtual key
+        codes.
+
+        :param key: A string indicating which key to be pressed.
+                    Available key options are:
+                    {'ESCAPE', '1', '2', '3', '4', '5', '6', '7', '8', '9',
+                    '0', '-', '=', 'BACKSPACE', 'TAB', 'Q', 'W', 'E', 'R', 'T',
+                    'Y', 'U', 'I', 'O', 'P', '[', ']', 'ENTER', 'LCTRL', 'A',
+                    'S', 'D', 'F', 'G', 'H', 'J', 'K', 'L', ';', "'", '`',
+                    'LSHIFT', 'BACKSLASH', 'Z', 'X', 'C', 'V', 'B', 'N', 'M',
+                    ',', '.', '/', 'RSHIFT', '*', 'LALT', 'SPACE', 'CAPS_LOCK',
+                    'F1', 'F2', 'F3', 'F4', 'F5', 'F6', 'F7', 'F8', 'F9',
+                    'F10', 'NUM_LOCK', 'SCROLL_LOCK', 'NUMPAD_7', 'NUMPAD_8',
+                    'NUMPAD_9', 'NUMPAD_-', 'NUMPAD_4', 'NUMPAD_5', 'NUMPAD_6',
+                    'NUMPAD_+', 'NUMPAD_1', 'NUMPAD_2', 'NUMPAD_3', 'NUMPAD_0',
+                    'NUMPAD_.', 'F11', 'F12', 'PRINT_SCREEN', 'PAUSE',
+                    'NUMPAD_ENTER', 'RCTRL', 'NUMPAD_/', 'RALT', 'HOME', 'UP',
+                    'PAGE_UP', 'LEFT', 'RIGHT', 'END', 'DOWN', 'PAGE_DOWN',
+                    'INSERT', 'DELETE', 'LWINDOWS', 'RWINDOWS', 'MENU'}.
+        """
+        key_press(key)
+
+    def key_release(self, key):
+        """Simulates a key release event.
+
+        Sends a scancode to the computer to report which key has been released.
+        Some games use DirectInput devices, and respond only to scancodes, not
+        virtual key codes. You can simulate DirectInput key releases using this
+        method. A call to the key_release() method usually follows a call to
+        the key_press() method of the same key.
+
+        :param key: A string indicating which key to be released.
+        """
+        key_release(key)
+
     def touch(self, pos, **kwargs):
         """
         Perform mouse click action
@@ -185,12 +231,36 @@ class Windows(Device):
         duration = kwargs.get("duration", 0.01)
         right_click = kwargs.get("right_click", False)
         button = "right" if right_click else "left"
-        coords = self._action_pos(pos)
-        coords = self._fix_op_pos(coords)
+        steps = kwargs.get("steps", 1)
+        offset = kwargs.get("offset", 0)
 
-        self.mouse.press(button=button, coords=coords)
+        start = self._action_pos(win32api.GetCursorPos())
+        end = self._action_pos(pos)
+        start_x, start_y = self._fix_op_pos(start)
+        end_x, end_y = self._fix_op_pos(end)
+
+        interval = float(duration) / steps
+        time.sleep(interval)
+
+        for i in range(1, steps):
+            x = int(start_x + (end_x-start_x) * i / steps)
+            y = int(start_y + (end_y-start_y) * i / steps)
+            self.mouse.move(coords=(x, y))
+            time.sleep(interval)
+
+        self.mouse.move(coords=(end_x, end_y))
+
+        for i in range(1, offset+1):
+            self.mouse.move(coords=(end_x+i, end_y+i))
+            time.sleep(0.01)
+
+        for i in range(offset):
+            self.mouse.move(coords=(end_x+offset-i, end_y+offset-i))
+            time.sleep(0.01)
+
+        self.mouse.press(button=button, coords=(end_x, end_y))
         time.sleep(duration)
-        self.mouse.release(button=button, coords=coords)
+        self.mouse.release(button=button, coords=(end_x, end_y))
 
     def double_click(self, pos):
         pos = self._fix_op_pos(pos)
@@ -200,6 +270,7 @@ class Windows(Device):
     def swipe(self, p1, p2, duration=0.8, steps=5):
         """
         Perform swipe (mouse press and mouse release)
+
         Args:
             p1: start point
             p2: end point
@@ -213,13 +284,6 @@ class Windows(Device):
         # 设置坐标时相对于整个屏幕的坐标:
         x1, y1 = self._fix_op_pos(p1)
         x2, y2 = self._fix_op_pos(p2)
-        # 双屏时，涉及到了移动的比例换算:
-        if len(self.screen.monitors) > 2:
-            ratio_x = (self.monitor["width"] + self.monitor["left"]) / self.main_monitor["width"]
-            ratio_y = (self.monitor["height"] + self.monitor["top"]) / self.main_monitor["height"]
-            x2 = int(x1 + (x2 - x1) * ratio_x)
-            y2 = int(y1 + (y2 - y1) * ratio_y)
-            p1, p2 = (x1, y1), (x2, y2)
 
         from_x, from_y = self._action_pos(p1)
         to_x, to_y = self._action_pos(p2)
@@ -238,6 +302,53 @@ class Windows(Device):
         time.sleep(interval)
         self.mouse.release(coords=(to_x, to_y))
 
+    def mouse_move(self, pos):
+        """Simulates a `mousemove` event.
+
+        Known bug:
+            Due to a bug in the pywinauto module, users might experience \
+            off-by-one errors when it comes to the exact coordinates of \
+            the position on screen.
+
+        :param pos: A tuple (x, y), where x and y are x and y coordinates of
+                    the screen to move the mouse to, respectively.
+        """
+        if not isinstance(pos, tuple) or len(pos) != 2:  # pos is not a 2-tuple
+            raise ValueError('invalid literal for mouse_move: {}'.format(pos))
+        try:
+            self.mouse.move(coords=self._action_pos(pos))
+        except ValueError:  # in case where x, y are not numbers
+            raise ValueError('invalid literal for mouse_move: {}'.format(pos))
+
+    def mouse_down(self, button='left'):
+        """Simulates a `mousedown` event.
+
+        :param button: A string indicating which mouse button to be pressed.
+                       Available mouse button options are:
+                       {'left', 'middle', 'right'}.
+        """
+        buttons = {'left', 'middle', 'right'}
+        if not isinstance(button, str) or button not in buttons:
+            raise ValueError('invalid literal for mouse_down(): {}'.format(button))
+        else:
+            coords = self._action_pos(win32api.GetCursorPos())
+            self.mouse.press(button=button, coords=coords)
+
+    def mouse_up(self, button='left'):
+        """Simulates a `mouseup` event.
+
+        A call to the mouse_up() method usually follows a call to the
+        mouse_down() method of the same mouse button.
+
+        :param button: A string indicating which mouse button to be released.
+        """
+        buttons = {'left', 'middle', 'right'}
+        if not isinstance(button, str) or button not in buttons:
+            raise ValueError('invalid literal for mouse_up(): {}'.format(button))
+        else:
+            coords = self._action_pos(win32api.GetCursorPos())
+            self.mouse.release(button=button, coords=coords)
+
     def start_app(self, path, **kwargs):
         """
         Start the application
